{
  description = "hostapps";
  inputs = {
    nixpkgs = {
      url = "github:nixos/nixpkgs/nixos-unstable";
    };
    flake-utils = {
      url = "github:numtide/flake-utils";
    };

  };
  outputs = { self, nixpkgs, flake-utils }@input:
    flake-utils.lib.eachDefaultSystem
      (system:
        let
          version = self.lastModifiedDate;
          pkgs = import nixpkgs {
            inherit system;
          };
        in
        {
          packages.hostapps = pkgs.poetry2nix.mkPoetryApplication {
            python = pkgs.python310;
            projectDir = ./.;
            propagatedBuildInputs = [
              pkgs.openssh
            ];
            overrides = pkgs.poetry2nix.overrides.withDefaults
              (
                self: super: {
                  pynetbox = super.pynetbox.overridePythonAttrs
                    (
                      old: {
                        propagatedBuildInputs = [ super.setuptools-scm ] ++ super.pynetbox.propagatedBuildInputs;
                      }
                    );
                }
              );
          };
          defaultPackage = self.packages.${system}.hostapps;
          devShells.default =
            let
              python = pkgs.python310.withPackages (
                ps: with ps; [
                  poetry
                  black
                  flake8
                ]
              );
            in
            pkgs.mkShell {
              buildInputs = with pkgs; [
                python
                openssh
              ];
              shellHook = ''
                export POETRY_VIRTUALENVS_IN_PROJECT=true
                export PS1='\[\033[1;34m\][hostapps:\w]\$\[\033[0m\] '
              '';
            };
        }
      );
}
